<?php

/**
 * @mods Bank
 * @package 2Moons
 * @author Hike
 * @licence MIT
 * @version 1.8.0
 */

class ShowBankPage extends AbstractGamePage
{
	
	public static $requireModule = 0;

	function __construct() 
	{
		parent::__construct();
	}

	function commission()
	{
		/**
		 * Une commision est prise par la banque pour chaque dépot (10%)
		 * A commission is taken by the bank for each deposit (10%)
		**/
		$commision_bank = 10 / 100;

		return $commision_bank;
	}
	
	function show() 
	{

		global $USER, $LNG;

		/**
		 * Permet de mettre à jour le ressource des planètes dans la base de donnée (non obligatoire)
		 * Allows to update the resource of the planets in the database (not required)
		**/
		$PlanetRess	= new ResourceUpdate();

		$db = Database::get();

		/**
		 * On vérifie si le joueur existe dans notre base de donnée
		 * We check if the player exists in our database
		**/
		$sql = "SELECT * FROM uni01_bank WHERE user_id = :user_id ;";
		$response = $db->selectSingle($sql, [':user_id' => $USER['id']]);

		/**
		 * Si le joueur existe pas on force nos variable à 0
		 * If the player does not exist we force our variables to 0
		**/
		if (!$response) {
			$response['bank_metal'] = 0;
			$response['bank_cristal'] = 0;
			$response['bank_deuterium'] = 0;
			$response['bank_darkmatter'] = 0;
			$response['bank_time_update'] = TIMESTAMP;
			$response['bank_time_retrait'] = TIMESTAMP;
		}

		$this->assign([
			'bank_metal' => $response['bank_metal'],
			'bank_cristal' => $response['bank_cristal'],
			'bank_deuterium' => $response['bank_deuterium'],
			'bank_darkmatter' => $response['bank_darkmatter'],
			'commision_bank' => sprintf($LNG['bank_commision'], $this->commission() * 100),
			'dernier_depot' => _date($LNG['php_tdformat'], $response['bank_time_update'], $USER['timezone']),
			'dernier_retrait' => _date($LNG['php_tdformat'], $response['bank_time_retrait'], $USER['timezone']),
		]);
				
		$this->display('page.bank.default.tpl');
	}

	function updateBank()
	{
		global $PLANET, $USER, $LNG;

		$db = Database::get();

		/**
		 * On mes les boutons pour la reception des ressource mis en banque
		 * I have the buttons for the reception of the resources put in the bank
		**/
		$depot_metal = HTTP::_GP('depot_metal', 0);
		$depot_cristal = HTTP::_GP('depot_cristal', 0);
		$depot_deuterium = HTTP::_GP('depot_deuterium', 0);
		$depot_darkmatter = HTTP::_GP('depot_darkmatter', 0);

		/**
		 * On vérifie que l'un des champs est remplis
		 * One verifies that one of the fields is filled
		**/
		if (empty($depot_metal) && empty($depot_cristal) && empty($depot_deuterium) && empty($depot_darkmatter)) {
			$this->printMessage($LNG['bank_error_empty']);
		}

		/**
		 * On fait les vérification pour être sur que le joueur dispose des ressources
		 * We make the checks to be sure that the player has the resources
		**/
		if ($PLANET['metal'] < $depot_metal || $PLANET['crystal'] < $depot_cristal || $PLANET['deuterium'] < $depot_deuterium || $USER['darkmatter'] < $depot_darkmatter) {
			$this->printMessage($LNG['bank_error_resource']);
		}

		/**
		 * On crée le total pour les ressources mis en banque moins la commision
		 * We create the total for the resources put in the bank less the commission
		**/
		$total_metal_bank = $depot_metal - ($depot_metal * $this->commission());
		$total_cristal_bank = $depot_cristal - ($depot_cristal * $this->commission());
		$total_deuterium_bank = $depot_deuterium - ($depot_deuterium * $this->commission());
		$total_darkmatter_bank = $depot_darkmatter - ($depot_darkmatter * $this->commission());

		/**
		 * On vérifie si le joueur à fait un premier dépot sinon on fait un INSERT INTO
		 * We check if the player made a first deposit otherwise we do an INSERT INTO
		**/
		$sql_controle = "SELECT user_id FROM uni01_bank WHERE user_id = :user_id ;";
		$response_controle = $db->selectSingle($sql_controle, [":user_id" => $USER['id']]);

		$sql = "UPDATE ";
		if (!$response_controle) {
			$sql = "INSERT INTO ";
		}

		/**
		 * On insert le tout dans notre base de donnée pour le ressources mise en bank
		 * We insert the whole in our database for resources put in bank
		**/
		$sql .= "uni01_bank SET 
			bank_metal = bank_metal + :bank_metal,
			bank_cristal = bank_cristal + :bank_cristal,
			bank_deuterium = bank_deuterium + :bank_deuterium,
			bank_darkmatter = bank_darkmatter + :bank_darkmatter,
			bank_time_update = :bank_time_update";

		if (!$response_controle) {
			$sql .= ", user_id = :user_id ;";
			$db->insert($sql, [
				':bank_metal' => $total_metal_bank,
				':bank_cristal' => $total_cristal_bank,
				':bank_deuterium' => $total_deuterium_bank,
				':bank_darkmatter' => $total_darkmatter_bank,
				':bank_time_update' => TIMESTAMP,
				':user_id' => $USER['id'],
			]);
		} else {
			$sql .= " WHERE user_id = :user_id ;";
			$db->update($sql, [
				':bank_metal' => $total_metal_bank,
				':bank_cristal' => $total_cristal_bank,
				':bank_deuterium' => $total_deuterium_bank,
				':bank_darkmatter' => $total_darkmatter_bank,
				':bank_time_update' => TIMESTAMP,
				':user_id' => $USER['id'],
			]);
		}

		/**
		 * On déduit de la planète ou se trouve le joueur les ressource mise dans la banque
		 * We deduce from the planet where the player is located the resource put in the bank
		**/
		$PLANET['metal'] -= $depot_metal;
		$PLANET['crystal'] -= $depot_cristal;
		$PLANET['deuterium'] -= $depot_deuterium;
		$USER['darkmatter'] -= $depot_darkmatter;

		$this->printMessage($LNG['bank_update_ok']);
	}

	function debitBank()
	{
		global $PLANET, $USER, $LNG;

		$db = Database::get();

		/**
		 * On mes les boutons pour la reception des ressource mis en banque
		 * I have the buttons for the reception of the resources put in the bank
		**/
		$debit_metal = HTTP::_GP('debit_metal', 0);
		$debit_cristal = HTTP::_GP('debit_cristal', 0);
		$debit_deuterium = HTTP::_GP('debit_deuterium', 0);
		$debit_darkmatter = HTTP::_GP('debit_darkmatter', 0);

		/**
		 * On vérifie si le joueur existe dans notre base de donnée
		 * We check if the player exists in our database
		**/
		$sql = "SELECT * FROM uni01_bank WHERE user_id = ".$USER['id']." ;";
		$response = $db->selectsingle($sql);

		if (!$response) {
			$this->printMessage($LNG['bank_error_joueur']);
		}

		/**
		 * On vérifie que l'un des champs est remplis
		 * One verifies that one of the fields is filled
		**/
		if (empty($debit_metal) && empty($debit_cristal) && empty($debit_deuterium) && empty($debit_darkmatter)) {
			$this->printMessage($LNG['bank_error_empty']);
		}

		/**
		 * On fait les vérification pour être sur que le joueur dispose des ressources
		 * We make the checks to be sure that the player has the resources
		**/
		if ($response['bank_metal'] < $debit_metal || $response['bank_cristal'] < $debit_cristal || $response['bank_deuterium'] < $debit_deuterium || $response['bank_darkmatter'] < $debit_darkmatter) {
			$this->printMessage($LNG['bank_error_resource']);
		}

		/**
		 * On fait notre requête sql pour déduire les ressource à la bank
		 * We make our sql query to deduce the resource to the bank
		**/
		$sql_debit = "UPDATE uni01_bank SET 
			bank_metal = bank_metal - :bank_metal,
			bank_cristal = bank_cristal - :bank_cristal,
			bank_deuterium = bank_deuterium - :bank_deuterium,
			bank_darkmatter = bank_darkmatter - :bank_darkmatter,
			bank_time_retrait = :bank_time_retrait WHERE user_id = :user_id ;";
		$db->update($sql_debit, [
				':bank_metal' => $debit_metal,
				':bank_cristal' => $debit_cristal,
				':bank_deuterium' => $debit_deuterium,
				':bank_darkmatter' => $debit_darkmatter,
				':bank_time_retrait' => TIMESTAMP,
				':user_id' => $USER['id'],
			]);

		/**
		 * On ajoute le retrait des ressources de la banque à la planète
		 * We add the withdrawal of resources from the bank to the planet
		**/
		$PLANET['metal'] += $debit_metal;
		$PLANET['crystal'] += $debit_cristal;
		$PLANET['deuterium'] += $debit_deuterium;
		$USER['darkmatter'] += $debit_darkmatter;

		$this->printMessage($LNG['bank_debit_ok']);
	}
}